@@ -13,7 +13,7 @@ test_that("insertTable", {
                                             collapse = "")
     return(randomString)
   }
-  bigInts <- 1:length(dayseq) + 2^40
+  bigInts <- bit64::runif64(length(dayseq))
   data <- data.frame(start_date = dayseq,
                      some_datetime = timeSeq,
                      person_id = as.integer(round(runif(length(dayseq), 1, 1e+07))),
@@ -34,8 +34,7 @@ test_that("insertTable", {
   details <- createConnectionDetails(dbms = "postgresql",
                                      user = Sys.getenv("CDM5_POSTGRESQL_USER"),
                                      password = URLdecode(Sys.getenv("CDM5_POSTGRESQL_PASSWORD")),
-                                     server = Sys.getenv("CDM5_POSTGRESQL_SERVER"),
-                                     schema = Sys.getenv("CDM5_POSTGRESQL_OHDSI_SCHEMA"))
+                                     server = Sys.getenv("CDM5_POSTGRESQL_SERVER"))
   connection <- connect(details)
   insertTable(connection = connection,
               tableName = "temp",
@@ -44,9 +43,9 @@ test_that("insertTable", {
               tempTable = TRUE)
   
   # Check data on server is same as local
-  data2 <- querySql(connection, "SELECT * FROM temp")
+  data2 <- querySql(connection, "SELECT * FROM temp", integer64AsNumeric = FALSE)
   names(data2) <- tolower(names(data2))
-  expect_equal(data, data2)
+  expect_equal(data, data2, check.attributes = FALSE)
   
   # Check data types
   res <- dbSendQuery(connection, "SELECT * FROM temp")
@@ -61,8 +60,7 @@ test_that("insertTable", {
   details <- createConnectionDetails(dbms = "sql server",
                                      user = Sys.getenv("CDM5_SQL_SERVER_USER"),
                                      password = URLdecode(Sys.getenv("CDM5_SQL_SERVER_PASSWORD")),
-                                     server = Sys.getenv("CDM5_SQL_SERVER_SERVER"),
-                                     schema = Sys.getenv("CDM5_SQL_SERVER_OHDSI_SCHEMA"))
+                                     server = Sys.getenv("CDM5_SQL_SERVER_SERVER"))
   connection <- connect(details)
   insertTable(connection = connection,
               tableName = "#temp",
@@ -71,9 +69,9 @@ test_that("insertTable", {
               tempTable = TRUE)
   
   # Check data on server is same as local
-  data2 <- querySql(connection, "SELECT * FROM #temp")
+  data2 <- querySql(connection, "SELECT * FROM #temp", integer64AsNumeric = FALSE)
   names(data2) <- tolower(names(data2))
-  expect_equal(data, data2)
+  expect_equal(data, data2, check.attributes = FALSE)
   
   # Check data types
   res <- dbSendQuery(connection, "SELECT * FROM #temp")
@@ -88,30 +86,35 @@ test_that("insertTable", {
   details <- createConnectionDetails(dbms = "oracle",
                                      user = Sys.getenv("CDM5_ORACLE_USER"),
                                      password = URLdecode(Sys.getenv("CDM5_ORACLE_PASSWORD")),
-                                     server = Sys.getenv("CDM5_ORACLE_SERVER"),
-                                     schema = Sys.getenv("CDM5_ORACLE_OHDSI_SCHEMA"))
+                                     server = Sys.getenv("CDM5_ORACLE_SERVER"))
+  schema <- Sys.getenv("CDM5_ORACLE_OHDSI_SCHEMA")
   connection <- connect(details)
   insertTable(connection = connection,
+              databaseSchema = schema,
               tableName = "temp",
               data = data,
               createTable = TRUE,
               tempTable = FALSE)
   
+  
+  # lowLevelQuerySql(connection, "SELECT * FROM all_tab_columns WHERE owner = 'OHDSI' AND table_name = 'TEMP'")
+  
   # Check data on server is same as local
-  data2 <- querySql(connection, "SELECT * FROM temp")
+  sql <- SqlRender::render( "SELECT * FROM @schema.temp", schema = schema)
+  data2 <- querySql(connection, sql, integer64AsNumeric = FALSE)
   names(data2) <- tolower(names(data2))
   data <- data[order(data$person_id), ]
   data2 <- data2[order(data2$person_id), ]
   row.names(data) <- NULL
   row.names(data2) <- NULL
-  expect_equal(data, data2)
+  expect_equal(data, data2, check.attributes = FALSE)
   
   # Check data types
-  res <- dbSendQuery(connection, "SELECT * FROM temp")
+  res <- dbSendQuery(connection, sprintf("SELECT * FROM %s.temp", schema))
   columnInfo <- dbColumnInfo(res)
   dbClearResult(res)
   expect_equal(as.character(columnInfo$field.type), c("DATE", "TIMESTAMP", "NUMBER", "NUMBER", "VARCHAR2", "NUMBER"))
-  
+
   disconnect(connection)
   
   # SQLite
@@ -126,13 +129,16 @@ test_that("insertTable", {
               tempTable = FALSE)
   
   # Check data on server is same as local
-  data2 <- querySql(connection, "SELECT * FROM temp")
+  data2 <- querySql(connection, "SELECT * FROM temp", integer64AsNumeric = FALSE)
   names(data2) <- tolower(names(data2))
   data <- data[order(data$person_id), ]
   data2 <- data2[order(data2$person_id), ]
   row.names(data) <- NULL
   row.names(data2) <- NULL
-  expect_equal(data, data2)
+
+  attr(data$some_datetime, "tzone") <- NULL
+  attr(data2$some_datetime, "tzone") <- NULL
+  expect_equal(data, data2, check.attributes = FALSE)
   
   # Check data types
   res <- dbSendQuery(connection, "SELECT * FROM temp")
